@@ -9,7 +9,7 @@ package Bio::Grep::Root;
 use strict;
 use warnings;
 
-use version; our $VERSION = qv('0.10.2');
+use version; our $VERSION = qv('0.10.3');
 
 use Bio::Root::Root;
 
@@ -129,6 +129,16 @@ sub _check_variable {
     return $value;
 }
 
+sub _cannot_print {
+    my ( $self, $filename ) = @_;
+    $self->throw(
+        -class => 'Bio::Root::IOException',
+        -text  => 'Cannot write to file',
+        -value => $filename
+    );
+    return;
+}
+
 1;    # Magic true value required at end of module
 __END__
 
@@ -219,7 +229,7 @@ Markus Riester, E<lt>mriester@gmx.deE<gt>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (C) 2007 by M. Riester. All rights reserved. 
+Copyright (C) 2007-2008 by M. Riester. 
 
 Based on Weigel::Search v0.13, Copyright (C) 2005-2006 by Max Planck 
 Institute for Developmental Biology, Tuebingen.
